@@ -21,7 +21,7 @@ def main():
     sequences from TCR AIRR-seq data or a radar plot with diversity metrics.",
         prog="TCRcloud")
     parser.add_argument('--version', action='version',
-                        version='%(prog)s 1.1.0')
+                        version='%(prog)s 1.2.1')
     subparsers = parser.add_subparsers(
         title="command options",
         help="The program has 4 options: cloud, radar, download or testdata",
@@ -32,7 +32,7 @@ def main():
     parser_cloud = subparsers.add_parser("cloud", help="Create a wordcloud \
         from TCR CDR3 data")
 
-    required_group = parser_cloud.add_argument_group("arguments")
+    # required_group = parser_cloud.add_argument_group("arguments")
 
     # required_group.add_argument("-r","--repertoire",
     #     type= tcrcloud.base.jsonfile,
@@ -40,29 +40,39 @@ def main():
     #     metavar= "repertoires.airr.json",
     #     required= True)
 
-    required_group.add_argument("-a", "--rearrangements", type=str,
-                                help="indicate the name of the AIRR Standards \
-                                rearrangements file",
-                                metavar="rearrangements.tsv", required=True)
-    required_group.add_argument("-c", "--colours", type=str,
-                                help="optional:indicate the name of a json \
-                                file to change the colours of the wordcloud",
-                                metavar="colours.json", required=False)
+    parser_cloud.add_argument("rearrangements", type=str,
+                              help="indicate the name of the AIRR Standards \
+                              rearrangements file",
+                              metavar="rearrangements.tsv")
+    parser_cloud.add_argument("-c", "--colours", type=str,
+                              help="indicate the name of a json file to \
+                              change the colours of the wordcloud",
+                              metavar="colours.json", required=False)
+    parser_cloud.add_argument("-l", "--legend", type=str,
+                              help="indicate if legend should be included, \
+                              default = True",
+                              metavar="True or False", default="True",
+                              required=False)
     parser_cloud.set_defaults(func=tcrcloud.cloud.wordcloud)
 
     # create subparser for making the radar
     parser_radar = subparsers.add_parser("radar", help="Create a radar plot \
         with diversity metrics")
-    required_group = parser_radar.add_argument_group("arguments")
-    required_group.add_argument("-a", "--rearrangements", type=str,
-                                help="indicate the name of the AIRR \
-                                Standards rearrangements file",
-                                metavar="rearrangements.tsv", required=True)
-    required_group.add_argument("-l", "--legend", type=str,
-                                help="optional:indicate the name of a json \
-                                file to convert repertoire_id to what you \
-                                want to appear in the legend",
-                                metavar="legend.json", required=False)
+
+    parser_radar.add_argument("rearrangements", type=str,
+                              help="indicate the name of the AIRR \
+                              Standards rearrangements file",
+                              metavar="rearrangements.tsv")
+    parser_radar.add_argument("-c", "--custom_legend", type=str,
+                              help="indicate the name of a json \
+                              file to convert repertoire_id to what you \
+                              want to appear in the legend",
+                              metavar="legend.json", required=False)
+    parser_radar.add_argument("-l", "--legend", type=str,
+                              help="indicate if legend should be included, \
+                              default = True",
+                              metavar="True or False", default="True",
+                              required=False)
     parser_radar.set_defaults(func=tcrcloud.radar.radar)
 
     # create subparser for downloading the rearregement data
@@ -71,13 +81,10 @@ def main():
                                             rearrangements data matching a \
                                             given repertoire metadata file")
 
-    required_group = parser_download.add_argument_group("required arguments")
-
-    required_group.add_argument("-r", "--repertoire", type=str,
-                                help="indicate the name of the \
-                                AIRR Standards repertoire file",
-                                metavar="repertoires.airr.json",
-                                required=True)
+    parser_download.add_argument("repertoire", type=str,
+                                 help="indicate the name of the \
+                                 AIRR Standards repertoire file",
+                                 metavar="repertoires.airr.json")
 
     parser_download.set_defaults(func=tcrcloud.download.airrdownload)
 
